import bpy
from bpy_extras import keyconfig_utils
from bl_keymap_utils import keymap_hierarchy
import rna_keymap_ui
from . import bl_info

class SelectModeShortcutsPreferences(bpy.types.AddonPreferences):
    bl_idname = __package__  # Must match the addon folder name exactly

    def draw(self, context):
        layout = self.layout
        self.draw_keymaps(context, layout)

    def draw_keymaps(self, context, layout):
        wm = bpy.context.window_manager
        kc = bpy.context.window_manager.keyconfigs.user

        # List of keymaps to display
        keymaps_info = [
            {
                'km_name': '3D View', 
                'operator_idname': 'object.editmode_toggle', 
                'label': 'Toggle Edit/Object Mode', 
                'select_mode': None
            },
            {
                'km_name': '3D View', 
                'operator_idname': 'object.editmode_toggle_selectmode', 
                'label': 'Face Select Mode', 
                'select_mode': 'FACE'
            },
            {
                'km_name': '3D View', 
                'operator_idname': 'object.editmode_toggle_selectmode', 
                'label': 'Vertex Select Mode', 
                'select_mode': 'VERT'
            },
            {
                'km_name': '3D View', 
                'operator_idname': 'object.editmode_toggle_selectmode', 
                'label': 'Edge Select Mode', 
                'select_mode': 'EDGE'
            },
        ]

        for km_info in keymaps_info:
            km = kc.keymaps.get(km_info['km_name'])
            if not km:
                continue

            for kmi in km.keymap_items:
                if kmi.idname == km_info['operator_idname']:
                    # If select_mode is specified, ensure it matches
                    if km_info['select_mode']:
                        if getattr(kmi.properties, 'select_mode', None) != km_info['select_mode']:
                            continue
                    # Draw the keymap item with a valid icon
                    row = layout.row(align=True)
                    row.label(text=km_info['label'])  # Replaced 'SHORTCUT' with 'KEY_HLT'
                    # Draw the keymap item
                    rna_keymap_ui.draw_kmi([], kc, km, kmi, row, 0)
                    break
